##  Creating Fact Sheets and Relations from the Inventory Builder Inbox
The Discoveries tab in the inventory builder inbox lists all the discovered fact sheets. Choose a fact sheet to view its details in the right-side pane, including the source of discovery, suggested fact sheet relations, and whether the fact sheet and its relations already exist or not. You can choose to either review each discovered item individually to create fact sheets and relations or create several fact sheets and relations at once.
![Inventory Builder Inbox](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742061c7a441014b4deff7157fddbbd_LowRes.png)
Inventory Builder Inbox
